<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  24910 => 'Sudatel',
  24911 => 'Sudatel',
  24912 => 'Sudatel',
  24990 => 'Zain',
  24991 => 'Zain',
  24992 => 'MTN',
  24993 => 'MTN',
  24995 => 'Network of The World Ltd',
  24996 => 'Zain',
  24999 => 'MTN',
);
